@@ -122,7 +122,7 @@ def parallel_states(aggregates):
     for name, comp in aggregates.items():
         for each in comp:
             parallel_states.extend(name for name in each.mapping.keys()
-                    if not name.endswith(u'START'))
+                    if not name.endswith('START'))
     return parallel_states
 
 
@@ -178,7 +178,7 @@ def inner_labels_to_floating(process):
             process.content.floating_labels.append(new_floating)
 
 
-def flatten(process, sep=u'_'):
+def flatten(process, sep='_'):
     ''' In-place update of the AST: flatten a model with nested states
         Rename inner states, procedures, etc. and move them to process level
     '''
@@ -502,7 +502,9 @@ def _rename_answer(ast, from_name, to_name):
             _, constant = each['content'] # get the constant
             rename_everything(constant, from_name, to_name)
         elif each['kind'] == 'closed_range':
-            pass  # TODO when supported
+            left, right = each['content']
+            rename_everything(left, from_name, to_name)
+            rename_everything(right, from_name, to_name)
     rename_everything(ast.transition, from_name, to_name)
 
 
@@ -701,7 +703,7 @@ def generate_asn1_datamodel(process: ogAST.Process, SEPARATOR: str=DEFAULT_SEPAR
     ''' Generate an ASN.1 model containing:
           - the state definition
           - a type describing the SDL context
-          - all user-defined SDL type (NEWTYPEs...)
+          - all user-defined SDL type (NEWTYPEs, SYNTYPEs...)
         This function is independent from specific backends.
     '''
 
@@ -780,7 +782,7 @@ def generate_asn1_datamodel(process: ogAST.Process, SEPARATOR: str=DEFAULT_SEPAR
 
     asn1_template.append(asn1_context)
 
-    # Add user-defined NEWTYPEs and CHOICE selector types
+    # Add user-defined NEWTYPEs, SYNTYPEs and CHOICE selector types
     choice_selections = []
     # a newtype may reuse another newtype, so we must update the list:
     types_with_proper_case.extend(process.user_defined_types.keys())
@@ -814,6 +816,10 @@ def generate_asn1_datamodel(process: ogAST.Process, SEPARATOR: str=DEFAULT_SEPAR
                 keys.append(f'{key}-present({idx+1})')
             asn1_template.append(
                     f'{prefixed_name.replace("_", "-").title()} ::= ENUMERATED {{' + ", ".join(keys) + '}')
+        elif sortdef.type.kind == 'ReferenceType':
+            # this is a SYNTYPE
+            asn1_template.append(
+                    f"{sortname} ::= {sortdef.type.ReferencedTypeName} ({sortdef.type.Min} .. {sortdef.type.Max})")
     asn1_template.append('END\n')
 
     # Write the ASN.1 file
