@@ -164,7 +164,9 @@ class EditableText(QGraphicsTextItem):
                     (hlink=hyperlink, text=text.replace('\n', '<br>')))
         else:
             self.setPlainText(text)
-        self.setTextInteractionFlags(Qt.TextEditorInteraction
+        self.setTextInteractionFlags( Qt.TextSelectableByMouse
+                                     | Qt.TextEditable
+                                     | Qt.TextSelectableByKeyboard
                                      | Qt.LinksAccessibleByMouse
                                      | Qt.LinksAccessibleByKeyboard)
         self.completer_has_focus = False
@@ -195,9 +197,19 @@ class EditableText(QGraphicsTextItem):
         fmt = QTextBlockFormat()
         fmt.setAlignment(alignment)
         cursor = self.textCursor()
+        # Store previous selection to set it back
+        if cursor.hasSelection():
+            selStart, selEnd = cursor.selectionStart(), cursor.selectionEnd()
+        else:
+            selStart = None
+        # format the document
         cursor.select(QTextCursor.Document)
         cursor.mergeBlockFormat(fmt)
         cursor.clearSelection()
+        if selStart is not None:
+            # reset selection as it was
+            cursor.setPosition(selStart)
+            cursor.setPosition(selEnd, QTextCursor.KeepAnchor)
         self.setTextCursor(cursor)
 
     def set_textbox_position(self):
@@ -358,6 +370,7 @@ class EditableText(QGraphicsTextItem):
             self.completer.resize(0, 0)
         super().mousePressEvent(event)
 
+
     # pylint: disable=C0103
     def focusOutEvent(self, event):
         '''
